@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.87 2005/01/03 21:49:30 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.93 2005/07/11 19:23:34 richb Exp $
  *
  *  Copyright (c) 1987-2005 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -50,7 +50,9 @@ char *base_desc[]  = {         /* Tooltips for each base value. */
 
 char *calc_res[] = {
     "accuracy", "base", "display", "modetype", "showregisters", "trigtype",
-    "showzeroes", "showthousands", "syntax"
+    "showzeroes", "showthousands", "syntax",
+    "register0", "register1", "register2", "register3", "register4",
+    "register5", "register6", "register7", "register8", "register9"
 };
 
 char *dtype_str[] = {          /* Strings for each display mode value. */
@@ -105,7 +107,7 @@ Vars v;            /* Calctool variables and options. */
  *
  *           |  a b c d e f g h i j k l m n o p q r s t u v w x y z
  *-----------+-----------------------------------------------------
- *  Lower:   |  a b c d e f     i     l m n   p   r s t u v     y
+ *  Lower:   |  a b c d e f     i     l m n   p   r s t u v   x
  *  Upper:   |  A   C D E F G     J K L   N   P   R S T       X Y
  *  Numeric: |  0 1 2 3 4 5 6 7 8 9
  *  Other:   |  @ . + - * / = % ( ) # < > [ ] { } | & ~ ^ ? ! :
@@ -904,11 +906,11 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 },       
 {        
     N_("<i>x</i><sup><i>y</i></sup>"),
-    N_("Raise displayed value to the power of y [y]"),
+    N_("Raise displayed value to the power of y [^]"),
     N_("X to the y"),
-    { 0, 0 },   
-    { GDK_y, 0 },
-    'y',
+    { GDK_SHIFT_MASK, GDK_SHIFT_MASK,  0 },
+    { GDK_caret,      GDK_asciicircum, 0 },
+    '^',
     M_NONE,
     do_calc,
     N_("^"),
@@ -950,7 +952,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     M_NONE,
     do_number,
     NULL,
-    none
+    number
 },
 {
     N_("E"),
@@ -962,7 +964,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     M_NONE,
     do_number,
     NULL,
-    none
+    number
 },
 {
     N_("F"),
@@ -974,7 +976,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     M_NONE,
     do_number,
     NULL,
-    none
+    number
 },
 {
     N_("Cos"),
@@ -1048,7 +1050,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     M_NONE,
     do_number,
     NULL,
-    none
+    number
 },
 {
     N_("B"),
@@ -1059,7 +1061,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     'B',
     M_NONE,
     do_number,
-    NULL
+    number
 },    
 {     
     N_("C"),
@@ -1071,7 +1073,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     M_NONE,
     do_number,
     NULL,
-    none
+    number
 },
 {
     N_("Or"),
@@ -1111,11 +1113,11 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 },
 {
     N_("Xor"),
-    N_("Bitwise XOR [^]"),
+    N_("Bitwise XOR [x]"),
     NULL,
-    { GDK_SHIFT_MASK, GDK_SHIFT_MASK,  0 },
-    { GDK_caret,      GDK_asciicircum, 0 },
-    '^',
+    { 0, 0 },   
+    { GDK_x, 0 },
+    'x',
     M_NONE,
     do_calc,
     N_(" Xor "),
@@ -1191,6 +1193,7 @@ do_calctool(int argc, char **argv)
     v->hyperbolic = 0;         /* Normal trig functions initially. */
     v->inverse    = 0;         /* No inverse functions initially. */
     v->down       = 0;         /* No mouse presses initially. */
+    v->warn_change_mode = 1;   /* Warn user when changing modes. */
 
     srand48((long) time((time_t *) 0));   /* Seed random number generator. */
 
@@ -1208,6 +1211,8 @@ do_calctool(int argc, char **argv)
 
     show_display(v->MPdisp_val);     /* Output in correct display mode. */
 
+    memset(&(v->e), 0, sizeof(struct exprm_state)); /* clear expression mode state */
+
     start_tool();                    /* Display the calculator. */
 }
 
